Net

Struct Net 

pub struct Net { /* private fields */ }
A Colored Petri Net (CPN).

Implementations

Source

impl Net

pub fn new(name: &str) -> Self

Constructs an empty, top-level net.

pub fn default(name: &str) -> Self

👎Deprecated

Constructs an empty, top-level net.

pub fn seed_rng(&mut self, seed: u64)

Seed (or re-seed) the PRNG.

This may be desirable to enable reproducible simulations.

pub fn name(&self) -> &str

Get the net’s name.

pub fn add_place<P>(&mut self, place: P) -> Result<()>
where P: Into<Place>,

Add a place with the given name to the net.

pub fn add_places<P, I>(&mut self, places: I) -> Result<()>
where P: Into<Place>, I: IntoIterator<Item = P>,

Add multiple places at once.

pub fn places(&self) -> impl Iterator<Item = &Place>

Get an iterator over references of the contained places.

pub fn add_transition(&mut self, transition: Transition) -> Result<()>

Add the given transition to the net.

After it has been added, use add_arc to connect it to places.

pub fn add_in_arc(&mut self, from: &str, to: &str, binding: &str) -> Result<()>

Add an arc from the place to the transition.

pub fn add_out_arc( &mut self, from: &str, to: &str, expression: Expression, ) -> Result<()>

Add an arc from the transition to the place.

pub fn add_arcs<'a, I>(&mut self, specs: I) -> Result<()>
where I: IntoIterator<Item = ArcSpec<'a>>,

Add multiple arcs at once.

This function is intended to be used together with the arcs! macro.

pub fn empty_marking(&self) -> Marking

Create an empty marking for this net.

pub fn simulation_step( &mut self, marking: &mut Marking, allow_non_determinism: bool, ) -> Result<()>

Perform one step in a net simulation, given the marking marking.

pub fn run_simulation( &mut self, marking: &mut Marking, allow_non_determinism: bool, ) -> Result<()>

Repeatedly call simulation_step until the net is dead.